# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ResponseDatasetSource(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'aws_role_arn': 'str',
        'bucket_name': 'str',
        'cluster_id': 'int',
        'cluster_name': 'str',
        'is_external': 'bool',
        'local_volume_config': 'OrmLocalVolumeConfig',
        'path': 'str',
        'type': 'str'
    }

    attribute_map = {
        'aws_role_arn': 'aws_role_arn',
        'bucket_name': 'bucket_name',
        'cluster_id': 'cluster_id',
        'cluster_name': 'cluster_name',
        'is_external': 'is_external',
        'local_volume_config': 'local_volume_config',
        'path': 'path',
        'type': 'type'
    }

    def __init__(self, aws_role_arn=None, bucket_name=None, cluster_id=None, cluster_name=None, is_external=None, local_volume_config=None, path=None, type=None, local_vars_configuration=None):  # noqa: E501
        """ResponseDatasetSource - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._aws_role_arn = None
        self._bucket_name = None
        self._cluster_id = None
        self._cluster_name = None
        self._is_external = None
        self._local_volume_config = None
        self._path = None
        self._type = None
        self.discriminator = None

        self.aws_role_arn = aws_role_arn
        self.bucket_name = bucket_name
        self.cluster_id = cluster_id
        self.cluster_name = cluster_name
        self.is_external = is_external
        if local_volume_config is not None:
            self.local_volume_config = local_volume_config
        self.path = path
        self.type = type

    @property
    def aws_role_arn(self):
        """Gets the aws_role_arn of this ResponseDatasetSource.  # noqa: E501


        :return: The aws_role_arn of this ResponseDatasetSource.  # noqa: E501
        :rtype: str
        """
        return self._aws_role_arn

    @aws_role_arn.setter
    def aws_role_arn(self, aws_role_arn):
        """Sets the aws_role_arn of this ResponseDatasetSource.


        :param aws_role_arn: The aws_role_arn of this ResponseDatasetSource.  # noqa: E501
        :type aws_role_arn: str
        """

        self._aws_role_arn = aws_role_arn

    @property
    def bucket_name(self):
        """Gets the bucket_name of this ResponseDatasetSource.  # noqa: E501


        :return: The bucket_name of this ResponseDatasetSource.  # noqa: E501
        :rtype: str
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        """Sets the bucket_name of this ResponseDatasetSource.


        :param bucket_name: The bucket_name of this ResponseDatasetSource.  # noqa: E501
        :type bucket_name: str
        """

        self._bucket_name = bucket_name

    @property
    def cluster_id(self):
        """Gets the cluster_id of this ResponseDatasetSource.  # noqa: E501


        :return: The cluster_id of this ResponseDatasetSource.  # noqa: E501
        :rtype: int
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """Sets the cluster_id of this ResponseDatasetSource.


        :param cluster_id: The cluster_id of this ResponseDatasetSource.  # noqa: E501
        :type cluster_id: int
        """

        self._cluster_id = cluster_id

    @property
    def cluster_name(self):
        """Gets the cluster_name of this ResponseDatasetSource.  # noqa: E501


        :return: The cluster_name of this ResponseDatasetSource.  # noqa: E501
        :rtype: str
        """
        return self._cluster_name

    @cluster_name.setter
    def cluster_name(self, cluster_name):
        """Sets the cluster_name of this ResponseDatasetSource.


        :param cluster_name: The cluster_name of this ResponseDatasetSource.  # noqa: E501
        :type cluster_name: str
        """

        self._cluster_name = cluster_name

    @property
    def is_external(self):
        """Gets the is_external of this ResponseDatasetSource.  # noqa: E501


        :return: The is_external of this ResponseDatasetSource.  # noqa: E501
        :rtype: bool
        """
        return self._is_external

    @is_external.setter
    def is_external(self, is_external):
        """Sets the is_external of this ResponseDatasetSource.


        :param is_external: The is_external of this ResponseDatasetSource.  # noqa: E501
        :type is_external: bool
        """
        if self.local_vars_configuration.client_side_validation and is_external is None:  # noqa: E501
            raise ValueError("Invalid value for `is_external`, must not be `None`")  # noqa: E501

        self._is_external = is_external

    @property
    def local_volume_config(self):
        """Gets the local_volume_config of this ResponseDatasetSource.  # noqa: E501


        :return: The local_volume_config of this ResponseDatasetSource.  # noqa: E501
        :rtype: OrmLocalVolumeConfig
        """
        return self._local_volume_config

    @local_volume_config.setter
    def local_volume_config(self, local_volume_config):
        """Sets the local_volume_config of this ResponseDatasetSource.


        :param local_volume_config: The local_volume_config of this ResponseDatasetSource.  # noqa: E501
        :type local_volume_config: OrmLocalVolumeConfig
        """

        self._local_volume_config = local_volume_config

    @property
    def path(self):
        """Gets the path of this ResponseDatasetSource.  # noqa: E501


        :return: The path of this ResponseDatasetSource.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this ResponseDatasetSource.


        :param path: The path of this ResponseDatasetSource.  # noqa: E501
        :type path: str
        """

        self._path = path

    @property
    def type(self):
        """Gets the type of this ResponseDatasetSource.  # noqa: E501


        :return: The type of this ResponseDatasetSource.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ResponseDatasetSource.


        :param type: The type of this ResponseDatasetSource.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseDatasetSource):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseDatasetSource):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class WorkspaceUpdateAPIPayload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cluster_name': 'str',
        'cluster_node_ids': 'list[int]',
        'init_script': 'str',
        'name': 'str',
        'ports': 'list[OrmWorkspacePort]',
        'resource_spec': 'OrmKernelResourceSpecField',
        'resource_spec_id': 'int',
        'volumes': 'ProtoVolumeMountRequests'
    }

    attribute_map = {
        'cluster_name': 'cluster_name',
        'cluster_node_ids': 'cluster_node_ids',
        'init_script': 'init_script',
        'name': 'name',
        'ports': 'ports',
        'resource_spec': 'resource_spec',
        'resource_spec_id': 'resource_spec_id',
        'volumes': 'volumes'
    }

    def __init__(self, cluster_name=None, cluster_node_ids=None, init_script=None, name=None, ports=None, resource_spec=None, resource_spec_id=None, volumes=None, local_vars_configuration=None):  # noqa: E501
        """WorkspaceUpdateAPIPayload - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._cluster_name = None
        self._cluster_node_ids = None
        self._init_script = None
        self._name = None
        self._ports = None
        self._resource_spec = None
        self._resource_spec_id = None
        self._volumes = None
        self.discriminator = None

        self.cluster_name = cluster_name
        if cluster_node_ids is not None:
            self.cluster_node_ids = cluster_node_ids
        self.init_script = init_script
        self.name = name
        if ports is not None:
            self.ports = ports
        if resource_spec is not None:
            self.resource_spec = resource_spec
        self.resource_spec_id = resource_spec_id
        if volumes is not None:
            self.volumes = volumes

    @property
    def cluster_name(self):
        """Gets the cluster_name of this WorkspaceUpdateAPIPayload.  # noqa: E501


        :return: The cluster_name of this WorkspaceUpdateAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._cluster_name

    @cluster_name.setter
    def cluster_name(self, cluster_name):
        """Sets the cluster_name of this WorkspaceUpdateAPIPayload.


        :param cluster_name: The cluster_name of this WorkspaceUpdateAPIPayload.  # noqa: E501
        :type cluster_name: str
        """

        self._cluster_name = cluster_name

    @property
    def cluster_node_ids(self):
        """Gets the cluster_node_ids of this WorkspaceUpdateAPIPayload.  # noqa: E501


        :return: The cluster_node_ids of this WorkspaceUpdateAPIPayload.  # noqa: E501
        :rtype: list[int]
        """
        return self._cluster_node_ids

    @cluster_node_ids.setter
    def cluster_node_ids(self, cluster_node_ids):
        """Sets the cluster_node_ids of this WorkspaceUpdateAPIPayload.


        :param cluster_node_ids: The cluster_node_ids of this WorkspaceUpdateAPIPayload.  # noqa: E501
        :type cluster_node_ids: list[int]
        """

        self._cluster_node_ids = cluster_node_ids

    @property
    def init_script(self):
        """Gets the init_script of this WorkspaceUpdateAPIPayload.  # noqa: E501


        :return: The init_script of this WorkspaceUpdateAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._init_script

    @init_script.setter
    def init_script(self, init_script):
        """Sets the init_script of this WorkspaceUpdateAPIPayload.


        :param init_script: The init_script of this WorkspaceUpdateAPIPayload.  # noqa: E501
        :type init_script: str
        """

        self._init_script = init_script

    @property
    def name(self):
        """Gets the name of this WorkspaceUpdateAPIPayload.  # noqa: E501


        :return: The name of this WorkspaceUpdateAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this WorkspaceUpdateAPIPayload.


        :param name: The name of this WorkspaceUpdateAPIPayload.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def ports(self):
        """Gets the ports of this WorkspaceUpdateAPIPayload.  # noqa: E501


        :return: The ports of this WorkspaceUpdateAPIPayload.  # noqa: E501
        :rtype: list[OrmWorkspacePort]
        """
        return self._ports

    @ports.setter
    def ports(self, ports):
        """Sets the ports of this WorkspaceUpdateAPIPayload.


        :param ports: The ports of this WorkspaceUpdateAPIPayload.  # noqa: E501
        :type ports: list[OrmWorkspacePort]
        """

        self._ports = ports

    @property
    def resource_spec(self):
        """Gets the resource_spec of this WorkspaceUpdateAPIPayload.  # noqa: E501


        :return: The resource_spec of this WorkspaceUpdateAPIPayload.  # noqa: E501
        :rtype: OrmKernelResourceSpecField
        """
        return self._resource_spec

    @resource_spec.setter
    def resource_spec(self, resource_spec):
        """Sets the resource_spec of this WorkspaceUpdateAPIPayload.


        :param resource_spec: The resource_spec of this WorkspaceUpdateAPIPayload.  # noqa: E501
        :type resource_spec: OrmKernelResourceSpecField
        """

        self._resource_spec = resource_spec

    @property
    def resource_spec_id(self):
        """Gets the resource_spec_id of this WorkspaceUpdateAPIPayload.  # noqa: E501


        :return: The resource_spec_id of this WorkspaceUpdateAPIPayload.  # noqa: E501
        :rtype: int
        """
        return self._resource_spec_id

    @resource_spec_id.setter
    def resource_spec_id(self, resource_spec_id):
        """Sets the resource_spec_id of this WorkspaceUpdateAPIPayload.


        :param resource_spec_id: The resource_spec_id of this WorkspaceUpdateAPIPayload.  # noqa: E501
        :type resource_spec_id: int
        """

        self._resource_spec_id = resource_spec_id

    @property
    def volumes(self):
        """Gets the volumes of this WorkspaceUpdateAPIPayload.  # noqa: E501


        :return: The volumes of this WorkspaceUpdateAPIPayload.  # noqa: E501
        :rtype: ProtoVolumeMountRequests
        """
        return self._volumes

    @volumes.setter
    def volumes(self, volumes):
        """Sets the volumes of this WorkspaceUpdateAPIPayload.


        :param volumes: The volumes of this WorkspaceUpdateAPIPayload.  # noqa: E501
        :type volumes: ProtoVolumeMountRequests
        """

        self._volumes = volumes

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkspaceUpdateAPIPayload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WorkspaceUpdateAPIPayload):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class S3DatasetCreateAPIPayload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'aws_role_arn': 'str',
        'description': 'str',
        'is_public': 'bool',
        'is_version_enabled': 'bool',
        'name': 'str',
        's3_path': 'str',
        'version_s3_path': 'str'
    }

    attribute_map = {
        'aws_role_arn': 'aws_role_arn',
        'description': 'description',
        'is_public': 'is_public',
        'is_version_enabled': 'is_version_enabled',
        'name': 'name',
        's3_path': 's3_path',
        'version_s3_path': 'version_s3_path'
    }

    def __init__(self, aws_role_arn=None, description=None, is_public=None, is_version_enabled=None, name=None, s3_path=None, version_s3_path=None, local_vars_configuration=None):  # noqa: E501
        """S3DatasetCreateAPIPayload - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._aws_role_arn = None
        self._description = None
        self._is_public = None
        self._is_version_enabled = None
        self._name = None
        self._s3_path = None
        self._version_s3_path = None
        self.discriminator = None

        self.aws_role_arn = aws_role_arn
        self.description = description
        if is_public is not None:
            self.is_public = is_public
        if is_version_enabled is not None:
            self.is_version_enabled = is_version_enabled
        self.name = name
        self.s3_path = s3_path
        if version_s3_path is not None:
            self.version_s3_path = version_s3_path

    @property
    def aws_role_arn(self):
        """Gets the aws_role_arn of this S3DatasetCreateAPIPayload.  # noqa: E501


        :return: The aws_role_arn of this S3DatasetCreateAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._aws_role_arn

    @aws_role_arn.setter
    def aws_role_arn(self, aws_role_arn):
        """Sets the aws_role_arn of this S3DatasetCreateAPIPayload.


        :param aws_role_arn: The aws_role_arn of this S3DatasetCreateAPIPayload.  # noqa: E501
        :type aws_role_arn: str
        """

        self._aws_role_arn = aws_role_arn

    @property
    def description(self):
        """Gets the description of this S3DatasetCreateAPIPayload.  # noqa: E501


        :return: The description of this S3DatasetCreateAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this S3DatasetCreateAPIPayload.


        :param description: The description of this S3DatasetCreateAPIPayload.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def is_public(self):
        """Gets the is_public of this S3DatasetCreateAPIPayload.  # noqa: E501


        :return: The is_public of this S3DatasetCreateAPIPayload.  # noqa: E501
        :rtype: bool
        """
        return self._is_public

    @is_public.setter
    def is_public(self, is_public):
        """Sets the is_public of this S3DatasetCreateAPIPayload.


        :param is_public: The is_public of this S3DatasetCreateAPIPayload.  # noqa: E501
        :type is_public: bool
        """

        self._is_public = is_public

    @property
    def is_version_enabled(self):
        """Gets the is_version_enabled of this S3DatasetCreateAPIPayload.  # noqa: E501


        :return: The is_version_enabled of this S3DatasetCreateAPIPayload.  # noqa: E501
        :rtype: bool
        """
        return self._is_version_enabled

    @is_version_enabled.setter
    def is_version_enabled(self, is_version_enabled):
        """Sets the is_version_enabled of this S3DatasetCreateAPIPayload.


        :param is_version_enabled: The is_version_enabled of this S3DatasetCreateAPIPayload.  # noqa: E501
        :type is_version_enabled: bool
        """

        self._is_version_enabled = is_version_enabled

    @property
    def name(self):
        """Gets the name of this S3DatasetCreateAPIPayload.  # noqa: E501


        :return: The name of this S3DatasetCreateAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this S3DatasetCreateAPIPayload.


        :param name: The name of this S3DatasetCreateAPIPayload.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def s3_path(self):
        """Gets the s3_path of this S3DatasetCreateAPIPayload.  # noqa: E501


        :return: The s3_path of this S3DatasetCreateAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._s3_path

    @s3_path.setter
    def s3_path(self, s3_path):
        """Sets the s3_path of this S3DatasetCreateAPIPayload.


        :param s3_path: The s3_path of this S3DatasetCreateAPIPayload.  # noqa: E501
        :type s3_path: str
        """
        if self.local_vars_configuration.client_side_validation and s3_path is None:  # noqa: E501
            raise ValueError("Invalid value for `s3_path`, must not be `None`")  # noqa: E501

        self._s3_path = s3_path

    @property
    def version_s3_path(self):
        """Gets the version_s3_path of this S3DatasetCreateAPIPayload.  # noqa: E501


        :return: The version_s3_path of this S3DatasetCreateAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._version_s3_path

    @version_s3_path.setter
    def version_s3_path(self, version_s3_path):
        """Sets the version_s3_path of this S3DatasetCreateAPIPayload.


        :param version_s3_path: The version_s3_path of this S3DatasetCreateAPIPayload.  # noqa: E501
        :type version_s3_path: str
        """

        self._version_s3_path = version_s3_path

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, S3DatasetCreateAPIPayload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, S3DatasetCreateAPIPayload):
            return True

        return self.to_dict() != other.to_dict()
